<?php

declare(strict_types=1);

namespace Drupal\Tests\simplehealthchecker\Functional;

use Drupal\Tests\BrowserTestBase;
use Symfony\Component\HttpFoundation\Response;

/**
 * Tests health Checker functionality.
 *
 * @group simplehealthchecker
 */
final class EndPointTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['simplehealthchecker'];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
  }

  /**
   * Tests the health-check endpoint.
   */
  public function testEndPoint(): void {
    // Test that the endpoint is accessible in normal mode.
    $this->drupalGet('/health-checker');
    $this->assertSession()->statusCodeEquals(Response::HTTP_OK);
    $this->assertSession()->responseContains('"timestamp"');

    // Enable maintenance mode.
    \Drupal::state()->set('system.maintenance_mode', TRUE);
    $this->rebuildContainer();

    // Test that the endpoint is still accessible in maintenance mode.
    $this->drupalGet('/health-checker');
    $this->assertSession()->statusCodeEquals(Response::HTTP_OK);
     $this->assertSession()->responseContains('"timestamp"');

    // Disable maintenance mode after the test.
    \Drupal::state()->set('system.maintenance_mode', FALSE);

  }
}
